<?php
/*
 * Plugin Name: Options for Twenty Twenty Premium
 * Version: 1.4.4
 * Plugin URI: https://webd.uk/product/options-for-twenty-twenty-upgrade/
 * Description: Adds even more options to modify the default Wordpress theme Twenty Twenty
 * Author: Webd Ltd
 * Author URI: https://webd.uk
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('options_for_twenty_twenty_premium_class')) {

	class options_for_twenty_twenty_premium_class {

        public static $version = '1.4.4';

		function __construct() {

            add_action('customize_register', array($this, 'oftt_customize_register'), 999);
            add_action('wp_head' , array($this, 'oftt_header_output'));
            add_action('load-post.php', array($this, 'oftt_theme_options_metabox_setup'));
            add_action('load-post-new.php', array($this, 'oftt_theme_options_metabox_setup'));
            add_action('widgets_init', array($this, 'oftt_widgets_init'), 11);
            add_filter('twentytwenty_social_icons_map', array($this, 'oftt_twentytwenty_social_icons_map'));
            add_filter('twentytwenty_svg_icons_social', array($this, 'oftt_twentytwenty_svg_icons_social'));
            add_action('init', array($this, 'oftt_archive_cover_template'));

            if (is_admin()) {

                add_filter('site_transient_update_plugins', 'ofttPremium::check_plugin_update');
                add_filter('plugins_api', 'ofttPremium::get_plugin_information', 10, 3);
                add_filter('after_plugin_row_' . plugin_basename(__FILE__), 'ofttPremium::activate_purchase_js', 10, 3);
                add_action('wp_ajax_oftt_activate_purchase', 'ofttPremium::activate_purchase');
                add_action('admin_notices', 'ofttPremium::upgrade_notice');
                add_filter('upgrader_pre_download', 'ofttPremium::upgrader_pre_download', 10, 3);
                add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'oftt_add_plugin_action_links'));
                add_filter('plugin_row_meta', 'ofttPremium::plugin_row_meta', 10, 4);

            } else {

                add_action('wp_enqueue_scripts', array($this, 'oftt_enqueue_scripts'));

            }

		}

		function oftt_add_plugin_action_links($links) {

			$settings_links = ofttCommon::plugin_action_links(admin_url('customize.php'), true);

			return array_merge($settings_links, $links);

		}

        function oftt_customize_register($wp_customize) {

            if (!class_exists('reset_customizer_class')) {

                $wp_customize->add_section('reset_customizer', array(
                    'title'     => __('Backup Customizer', 'reset-customizer'),
                    'description'  => __('Reset Customizer plugin allows you to backup and restore your customizer settings. You can also reset the options within each section of the customizer to their defaults without affecting other settings.', 'options-for-twenty-twenty'),
                    'priority'     => 0
                ));

                ofttCommon::add_hidden_control($wp_customize, 'install_reset_customizer', 'reset_customizer', '', sprintf(wp_kses(__('<a href="%s" class="button-primary">Install Reset Customizer plugin</a>.', 'options-for-twenty-twenty'), array('a' => array('href' => array(), 'class' => array()))), esc_url(wp_nonce_url(add_query_arg(array('action' => 'install-plugin', 'plugin' => 'reset-customizer'), self_admin_url('update.php')), 'install-plugin_reset-customizer'))));

            }



            $upgrade_link = '<a href="' . ofttCommon::upgrade_link() . '" title="' . __('Upgrade to Options for Twenty Twenty Premium', 'options-for-twenty-twenty') . '">' . __('Upgrade to Options for Twenty Twenty Premium', 'options-for-twenty-twenty') . '</a>';
            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'options-for-twenty-twenty');



            $control_label = __('Archive Cover Template', 'options-for-twenty-twenty');
            $control_description = __('Use the Cover Template for taxonomy pages.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $taxonomies = array();

            foreach(get_taxonomies(array('public' => 'true'), 'objects') as $taxonomy) {

                $taxonomies[$taxonomy->name] = __('Taxonomy: ', 'options-for-twenty-twenty') . ': ' . $taxonomy->label;

            }

            unset($taxonomies['post_format']);

            $wp_customize->add_setting('archive_cover_template', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'archive_cover_template', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'archive_cover_template',
                'choices'       => $taxonomies
            )));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'archive_cover_template', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('True Parallax Background Image', 'options-for-twenty-twenty');
            $control_description = __('Turn on "true parallax" scrolling for the background image.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission()) {

            $wp_customize->add_setting('true_parallax_background_image', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('true_parallax_background_image', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'true_parallax_background_image',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'true_parallax_background_image', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Inject Sidebar', 'options-for-twenty-twenty');
            $control_description = __('Inject a sidebar into the theme by choosing where you want it shown.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $sidebar_locations = array(
                'all' => __('Everywhere', 'options-for-twenty-twenty'),
                'front_page' => __('Front Page', 'options-for-twenty-twenty'),
                'home' => __('Main Blog Page', 'options-for-twenty-twenty'),
                'single' => __('Single Posts', 'options-for-twenty-twenty'),
                'archive' => __('Archive Pages', 'options-for-twenty-twenty')
            );

            foreach(get_post_types(array('public' => 'true')) as $post_type) {

                $post_type_object = get_post_type_object($post_type);
                $sidebar_locations['post_type/' . $post_type] = __('Post Type: ', 'options-for-twenty-twenty') . $post_type_object->label;

                foreach (get_object_taxonomies($post_type, 'objects') as $taxonomy) {

                    $sidebar_locations['taxonomy/' . $post_type . '/' . $taxonomy->name] = $post_type_object->label . __(' Taxonomy: ', 'options-for-twenty-twenty') . $taxonomy->label;

                }

            }

            $wp_customize->add_setting('inject_sidebar', array(
                'default'       => array(),
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_multiple_options'
            ));
            $wp_customize->add_control(new webd_Customize_Control_Checkbox_Multiple($wp_customize, 'inject_sidebar', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'inject_sidebar',
                'choices'       => $sidebar_locations
            )));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'inject_sidebar', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Alignment', 'options-for-twenty-twenty');
            $control_description = __('Choose to show the sidebar on the right or the left.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission()) {

            $wp_customize->add_setting('sidebar_alignment', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('sidebar_alignment', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_alignment',
                'type'          => 'select',
                'choices'       => array(
                    'left' => __('Left', 'options-for-twenty-twenty'),
                    '' => __('Right (default)', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_alignment', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Width', 'options-for-twenty-twenty');
            $control_description = __('Set the width of the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_width', array(
                'default'           => 33,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_width', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 20,
                    'max'   => 80,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_width', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Horizontal Padding', 'options-for-twenty-twenty');
            $control_description = __('Set the width of the padding to the left and right of widgets in the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_horizontal_padding', array(
                'default'           => 21,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_horizontal_padding', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_horizontal_padding',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_horizontal_padding', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Widget Padding', 'options-for-twenty-twenty');
            $control_description = __('Set the height of the padding in-between widgets in the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_widget_padding', array(
                'default'           => 9,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_widget_padding', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_widget_padding',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 9,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_widget_padding', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Title Font Size', 'options-for-twenty-twenty');
            $control_description = __('Set the font size of widget titles in the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_title_font_size', array(
                'default'           => 40,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_title_font_size', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_title_font_size',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 9,
                    'max'   => 60,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_title_font_size', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sidebar Text Font Size', 'options-for-twenty-twenty');
            $control_description = __('Set the font size of widget text in the injected sidebar.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sidebar_text_font_size', array(
                'default'           => 18,
                'transport'         => 'refresh',
                'sanitize_callback' => 'absint'
            ));
            $wp_customize->add_control('sidebar_text_font_size', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_general',
                'settings'      => 'sidebar_text_font_size',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 6,
                    'max'   => 30,
                    'step'  => 1
                ),
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sidebar_text_font_size', 'oftt_general', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Limit Search to Post Type', 'options-for-twenty-twenty');
            $control_description = __('Limit the site search to a specific post type.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $post_type_objects = get_post_types(array('exclude_from_search' => false), 'objects');
            $post_types = array(
                '' => __('All (Default)', 'options-for-twenty-twenty')
            );

            foreach ($post_type_objects as $post_type) {

                $post_types[$post_type->name] = $post_type->label;

            }

            $wp_customize->add_setting('search_post_type', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('search_post_type', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'search_post_type',
                'type'          => 'select',
                'choices'       => $post_types
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'search_post_type', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            if (get_theme_mod('toggle_use_dashicon')) {

                if (!get_theme_mod('nav_toggle_dashicon')) {

                    set_theme_mod('nav_toggle_dashicon', 'menu');

                }

                remove_theme_mod('toggle_use_dashicon');

            }

            if (file_exists(ABSPATH . WPINC . '/css/dashicons.css')) {

                $dashicons_css = explode("\n", implode('', file(ABSPATH . WPINC . '/css/dashicons.css')));
                $dashicons = array();

                foreach ($dashicons_css as $css_entry) {

                    if (strlen($css_entry) > 10 && substr($css_entry, 0, 11) === '.dashicons-') {

                        $dashicon_class = sanitize_key(preg_replace(array('/^.dashicons-/', '/:before {$/'), '', $css_entry));
                        $dashicons[$dashicon_class] = __(ucwords(str_replace('-', ' ', $dashicon_class)), 'options-for-twenty-twenty');

                    }

                }

                asort($dashicons);

                $dashicons =  array(
                    '' => __('Default (...)')
                ) + $dashicons;

                $control_label = __('Custom Toggle Dashicon', 'options-for-twenty-twenty');
                $control_description = sprintf(wp_kses(__('Choose your own <a href="%s">dashicon</a> for the button that opens the expanded / mobile menu.', 'options-for-twenty-twenty'), array('a' => array('href' => array()))), esc_url('https://developer.wordpress.org/resource/dashicons/'));

                if (ofttPremium::request_permission()) {

                    $wp_customize->remove_control('toggle_use_dashicon');

                    $wp_customize->add_setting('nav_toggle_dashicon', array(
                        'default'       => '',
                        'type'          => 'theme_mod',
                        'transport'     => 'refresh',
                        'sanitize_callback' => 'ofttCommon::sanitize_options'
                    ));
                    $wp_customize->add_control('nav_toggle_dashicon', array(
                        'label'         => $control_label,
                        'description'   => $control_description,
                        'section'       => 'oftt_navigation',
                        'settings'      => 'nav_toggle_dashicon',
                        'type'          => 'select',
                        'choices'       => $dashicons
                    ));

                } else {

                    ofttCommon::add_hidden_control($wp_customize, 'nav_toggle_dashicon', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

                }

            }

            $control_label = __('Animate Close Menu Icon', 'options-for-twenty-twenty');
            $control_description = __('Animate the close menu toggle on the expanded menu.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('animate_close_toggle', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('animate_close_toggle', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'animate_close_toggle',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'animate_close_toggle', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Desktop Menu', 'options-for-twenty-twenty');
            $control_description = __('Fix the site navigation to the top of the page on large screens.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_desktop_menu', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_desktop_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_desktop_menu',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Off', 'options-for-twenty-twenty'),
                    'bar' => __('Sticky Menu Bar', 'options-for-twenty-twenty'),
                    'button' => __('Sticky Expanded Menu Button', 'options-for-twenty-twenty'),
                    'hidden' => __('Sticky Button (Hidden in Bar)', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_desktop_menu', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Mobile Menu', 'options-for-twenty-twenty');
            $control_description = __('Fix the site navigation to the top right on scroll down on small screens.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_mobile_menu', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('sticky_mobile_menu', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_mobile_menu',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Off', 'options-for-twenty-twenty'),
                    'bar' => __('Sticky Menu Bar', 'options-for-twenty-twenty'),
                    'button' => __('Sticky Menu Button', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_mobile_menu', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Menu Button Background Color', 'options-for-twenty-twenty');
            $control_description = __('Set the background color of the sticky menu button.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('menu_button_background_color', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'menu_button_background_color', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
            	'settings'      => 'menu_button_background_color'
            )));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'menu_button_background_color', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Sticky Menu Dropshadow', 'options-for-twenty-twenty');
            $control_description = __('Add a dropshadow to the sticky menus.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_dropshadow', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_dropshadow', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_menu_dropshadow',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_menu_dropshadow', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Animate Dropshadow', 'options-for-twenty-twenty');
            $control_description = __('Give a 3D animation to the dropshadow on sticky menus.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('sticky_menu_shadow_animate', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('sticky_menu_shadow_animate', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_navigation',
                'settings'      => 'sticky_menu_shadow_animate',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'sticky_menu_shadow_animate', 'oftt_navigation', $control_label, $control_description . ' ' . $upgrade_nag);

}



            $control_label = __('Parallax Featured Images', 'options-for-twenty-twenty');
            $control_description = __('Turn on "true parallax" scrolling for featured images.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('parallax_featured_images', array(
                'default'       => false,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_boolean'
            ));
            $wp_customize->add_control('parallax_featured_images', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_content',
                'settings'      => 'parallax_featured_images',
                'type'          => 'checkbox'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'parallax_featured_images', 'oftt_content', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Footer Order', 'options-for-twenty-twenty');
            $control_description = __('Order the sections in the site\'s footer.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('footer_order', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('footer_order', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'footer_order',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Menu -> Widgets -> Copyright', 'options-for-twenty-twenty'),
                    '021' => __('Menu -> Copyright -> Widgets', 'options-for-twenty-twenty'),
                    '120' => __('Widgets -> Copyright -> Menu', 'options-for-twenty-twenty'),
                    '102' => __('Widgets -> Menu -> Copyright', 'options-for-twenty-twenty'),
                    '210' => __('Copyright -> Widgets -> Menu', 'options-for-twenty-twenty'),
                    '201' => __('Copyright -> Menu -> Widgets', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'footer_order', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Footer Sidebars', 'options-for-twenty-twenty');
            $control_description = __('Add a third or fourth widget ready sidebar to the footer area of the theme.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('footer_sidebars', array(
                'default'       => '',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('footer_sidebars', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'footer_sidebars',
                'type'          => 'select',
                'choices'       => array(
                    '1' => __('1 Footer Sidebar', 'options-for-twenty-twenty'),
                    '' => __('2 Footer Sidebars', 'options-for-twenty-twenty'),
                    '3' => __('3 Footer Sidebars', 'options-for-twenty-twenty'),
                    '4' => __('4 Footer Sidebars', 'options-for-twenty-twenty')
                )
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'footer_sidebars', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Replace "Powered by" Text', 'options-for-twenty-twenty');
            $control_description = __('Provide alternate text to replace "Proudly powered by Wordpress".', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('replace_powered_by_wordpress', array(
                'default'           => '',
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => 'wp_kses_post'
            ));
            $wp_customize->add_control('replace_powered_by_wordpress', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'replace_powered_by_wordpress',
                'type'          => 'text'
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'replace_powered_by_wordpress', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $pages  = get_pages(array('post_status' => array('publish')));

            $possible_copyright_pages = array(0 => 'Select ...');

            if ($pages) {

                foreach ($pages as $page) {

                    $possible_copyright_pages[$page->ID] = $page->post_title;

                }

            }

            $wp_customize->remove_setting('privacy_link');
            $wp_customize->remove_control('privacy_link');

            $control_label = __('Enable Copyright Link', 'options-for-twenty-twenty');
            $control_description = __('Injects a link to a chosen "Copyright" page.', 'options-for-twenty-twenty');

if (ofttPremium::request_permission() == true) {

            $wp_customize->add_setting('copyright_link', array(
                'default'       => 0,
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $wp_customize->add_control('copyright_link', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftt_footer',
                'settings'      => 'copyright_link',
                'type'          => 'select',
                'choices'       => $possible_copyright_pages
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'copyright_link', 'oftt_footer', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $control_label = __('Background Slider', 'options-for-twenty-twenty');
            $control_description = sprintf(
                wp_kses(__('Places a <a href="%s">MetaSlider</a> slider in the background of the Cover Template.', 'options-for-twenty-twenty'), array('a' => array('href' => array()))),
                esc_url(add_query_arg( array(
                    's' => 'ml-slider',
                    'tab' => 'search',
                    'type' => 'term'
                ), admin_url('plugin-install.php')))
            );

if (ofttPremium::request_permission()) {

            $wp_customize->add_setting('slider_cover', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => 'ofttCommon::sanitize_options'
            ));
            $installed_sliders = array();

            if (class_exists('MetaSliderPlugin')) {

                $installed_sliders[] = 'ml-slider';

            }

            $sliders_array = array('' => 'No slider');

            if (!empty($installed_sliders)) {

                $available_sliders = get_posts(array(
                    'post_type' => $installed_sliders,
                    'posts_per_page' => -1,
                ));

                foreach ($available_sliders as $available_slider) {

                    $sliders_array[$available_slider->ID] = $available_slider->post_title;

                }

            }

            $wp_customize->add_control('slider_cover', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'cover_template_options',
                'settings'      => 'slider_cover',
                'type'          => 'select',
                'choices'       => $sliders_array
            ));

} else {

            ofttCommon::add_hidden_control($wp_customize, 'slider_cover', 'cover_template_options', $control_label, $control_description . ' ' . $upgrade_nag);

}

            $wp_customize->remove_control('expanded_menu_widgets_1');
            $wp_customize->remove_control('expanded_menu_widgets_2');
            $wp_customize->remove_control('mobile_menu_widgets_1');
            $wp_customize->remove_control('mobile_menu_widgets_2');

        }

        function oftt_header_output() {

            global $post;

?>
<!--Customizer CSS-->
<style type="text/css">
.modal-menu .widget {
    border-top: 1px solid #dbdbdb;
    padding: 2.5rem 0;
}
.modal-menu .widget a {
    display: inline;
    padding: 0;
}
<?php

if (ofttPremium::request_permission()) {

            if (get_theme_mod('archive_cover_template')) {

?>
.archive .featured-media::before {
        display: none;
}
.archive .featured-media {
    margin-top: 5rem;
}
@media (min-width: 700px) {
    .archive .featured-media {
        margin-top: 6rem;
    }
}
<?php

            }

            if (get_theme_mod('true_parallax_background_image')) {

                add_action('get_footer', array($this, 'oftt_inject_background_image_true_parallax'));

            }

            if (get_theme_mod('inject_sidebar') || ((is_single() || is_page()) && get_post_meta(get_the_ID(), 'oftt_show_sidebar', true) == '1')) {

                add_filter('wp_footer', array($this, 'oftt_inject_sidebar'));

?>
@media (min-width: 700px) {
    #site-content-wrapper > .post-inner>.entry-content > .alignwide {
        max-width: 100%;
        width: 100%;
	}
    #site-content-wrapper {
        display: flex;
    }
<?php

                $mod = get_theme_mod('sidebar_width');

                if ($mod) {
?>
    #site-content-wrapper>#site-content,
    #site-content-wrapper>.post-inner {
        width: <?php echo 100 - absint($mod); ?>%;
    }
    #site-content-wrapper>#sidebar {
        width: <?php echo absint($mod); ?>%;
    }  
<?php
                } else {

?>
    #site-content-wrapper>#site-content,
    #site-content-wrapper>.post-inner {
        width: 67%;
    }
    #site-content-wrapper>#sidebar {
        width: 33%;
    }  
<?php

                }

                $mod = absint(get_theme_mod('sidebar_widget_padding'));

                if ($mod) {

?>
#sidebar .widget {
    padding: <?php echo number_format((($mod - 1) * 5 / 8), 2); ?>rem 0;
}
@media (min-width: 700px) {
    #sidebar .widget {
        padding: <?php echo ($mod -1); ?>rem 0;
    }
}
<?php

                }

?>
}
#site-content-wrapper {
    margin: 0 auto;
}
#sidebar {
    padding: 0 2rem;
}
#sidebar section:first-of-type {
    padding-top: 0;
}
<?php

                $mod = absint(get_theme_mod('sidebar_horizontal_padding'));

                if ($mod) {

?>
#sidebar {
    padding: 0 <?php echo (($mod - 1) / 10); ?>rem;
}
<?php

                }

                $mod = get_theme_mod('content_width');

                if ($mod && !is_page_template(array('templates/template-full-width.php'))) {

                    ofttCommon::generate_css('#site-content-wrapper', 'max-width', 'content_width');

                } elseif (!is_page_template(array('templates/template-full-width.php'))) {

?>
#site-content-wrapper {
    max-width: 58rem;
}
<?php

                }

                ofttCommon::generate_css('#site-content-wrapper', 'flex-direction', 'sidebar_alignment', '', '', 'row-reverse');

            }

            ofttCommon::generate_css('#sidebar', 'font-size', 'search_post_type', '', '', (get_theme_mod('sidebar_text_font_size') / 10) . 'rem');

            if (get_theme_mod('search_post_type')) {

                add_filter('get_search_form', array($this, 'oftt_get_search_form'), 10, 2);

            }

            $mod = get_theme_mod('sidebar_title_font_size');

            if ($mod) {

?>
#sidebar .heading-size-3 {
    font-size: <?php echo ($mod * 0.28 / 4); ?>rem;
}
@media (min-width: 700px) {
    #sidebar .heading-size-3 {
        font-size: <?php echo ($mod / 10); ?>rem;
    }
}
<?php

            }

            if (get_theme_mod('toggle_use_dashicon') || get_theme_mod('nav_toggle_dashicon')) {

                global $options_for_twenty_twenty_object;

                remove_action('wp_footer', array($options_for_twenty_twenty_object, 'oftt_toggle_use_dashicon'));
                add_action('wp_footer', array($this, 'oftt_toggle_use_dashicon'));

?>
.nav-toggle .toggle-icon {
    height: auto;
}
.nav-toggle .toggle-inner {
    padding-top: 0.2rem;
}
.nav-toggle .toggle-inner .dashicons, .dashicons-before:before {
    width: 23px;
    height: 23px;
    font-size: 23px;
}
<?php

            }

            if (get_theme_mod('animate_close_toggle')) {

?>
button.close-nav-toggle svg {
    transition: transform .2s ease-in-out;
}
button.close-nav-toggle:hover svg {
    transform: rotate(180deg);
}
<?php

            }

            add_filter('wp_nav_menu', array($this, 'oftt_menu_widgets'), 10, 2);

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_header', true) == '1') {

                if (get_theme_mod('hide_all_headers')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
header.entry-header {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_header_title', true) == '1') {

                if (get_theme_mod('hide_all_header_titles')) { $show_or_hide = 'visible'; } else { $show_or_hide = 'hidden'; }

?>
header.entry-header h1.entry-title {
    visibility: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftt_hide_featured_image', true) == '1') {

                if (get_theme_mod('hide_all_featured_images')) { $show_or_hide = 'block'; } else { $show_or_hide = 'none'; }

?>
.featured-media {
    display: <?php echo $show_or_hide; ?>;
}
<?php

            }

            if (get_theme_mod('sticky_mobile_menu') || get_theme_mod('sticky_desktop_menu')) {

                add_action('wp_footer', array($this, 'oftt_sticky_menu'));

            }

            if (get_theme_mod('sticky_mobile_menu') == 'button') {

?>
@media (max-width: 1000px) {
<?php

                if (get_theme_mod('menu_button_background_color')) {

?>
    #site-header .sticky {
        background-color: <?php echo get_theme_mod('menu_button_background_color'); ?>;
    }
<?php

                } else {

?>
    #site-header div:not(.search-modal, .search-modal-inner), #site-header .sticky {
        background-color: inherit;
    }
<?php

                }

?>
	#site-header .sticky {
        position: fixed;
        z-index: 11;
		top: 1rem;
		right: 1rem;
		bottom: auto;
		height: 6.6rem;
		border-radius: 100%;
    }<?php if (!get_theme_mod('hide_toggle_text')) { ?>
	#site-header .sticky .toggle-inner {
		margin-top: -1.5rem;
	}<?php } ?>
	#site-header .sticky .toggle-inner .toggle-text {
        top: 100%
	}
    .admin-bar #site-header .sticky {
		top: calc(1rem + 32px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem);
    }
}
@media (max-width: 782px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem + 46px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: 1rem;
    }
}
<?php

            }

            if (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') {

?>
@media (min-width: 1000px) {
<?php

                if (get_theme_mod('sticky_desktop_menu') == 'hidden') {

?>
    #site-header .desktop-nav-toggle:not(.sticky) {
        position: absolute;
        right: -100vh;
    }
    .header-footer-group table caption, body:not(.overlay-header) .header-inner .toggle-wrapper::before {
        background: none;
    }
<?php

                }

                if (get_theme_mod('menu_button_background_color')) {

?>
    #site-header .sticky {
        background-color: <?php echo get_theme_mod('menu_button_background_color'); ?>;
    }
<?php

                } else {

?>
    #site-header div:not(.search-modal, .search-modal-inner), #site-header .sticky {
        background-color: inherit;
    }
<?php

                }

?>
	#site-header .sticky {
        position: fixed;
        z-index: 11;
		top: 1rem;
		right: 1rem;
		bottom: auto;
		height: 6.6rem;
		border-radius: 100%;
		padding: 0 1.8rem 0 2.2rem;
    }<?php if (!get_theme_mod('hide_toggle_text')) { ?>
	#site-header .sticky .toggle-inner {
		margin-top: -1.5rem;
	}<?php } ?>
	#site-header .sticky .toggle-inner .toggle-text {
        top: 50%
	}
    .admin-bar #site-header .sticky {
		top: calc(1rem + 32px);
    }
}
@media (max-width: 782px) {
    .admin-bar #site-header .sticky {
		top: calc(1rem + 46px);
    }
}
@media (max-width: 600px) {
    .admin-bar #site-header .sticky {
		top: 1rem;
    }
}
<?php

            }

            if (get_theme_mod('sticky_mobile_menu') == 'bar') {

?>
@media (max-width: 1000px) {
    #site-header, .overlay-header #site-header {
        position: fixed;
        top: 0;
        right: 0;
        left: 0;
        z-index: 11;
    }
}
.admin-bar #site-header {
    top: 0;
}
@media screen and (min-width: 601px) {
    .admin-bar #site-header {
        top: 46px;
    }
}
@media screen and (min-width: 783px) {
    .admin-bar #site-header {
        top: 32px;
    }
}
@media screen and (min-width: 1000px) {
    .admin-bar #site-header {
        top: 0;
    }
}
<?php

            }

            if (get_theme_mod('sticky_desktop_menu') == 'bar') {

?>
@media (min-width: 1000px) {
    #site-header, .overlay-header #site-header {
        position: fixed;
        top: 0;
        right: 0;
        left: 0;
        z-index: 11;
    }
    .admin-bar #site-header {
        top: 32px;
    }
}
<?php

            }

            if (get_theme_mod('sticky_menu_dropshadow') && get_theme_mod('sticky_mobile_menu') == 'bar') {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (max-width: 1000px) {
    #site-header {
        transition: box-shadow 0.3s ease-in-out;
    }
    #site-header.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (max-width: 1000px) {
    #site-header {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow') && get_theme_mod('sticky_desktop_menu') == 'bar') {

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
@media (min-width: 1000px) {
    #site-header {
        transition: box-shadow 0.6s ease-in-out;
    }
    #site-header.shadow {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                } else {

?>
@media (min-width: 1000px) {
    #site-header {
        box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    }
}
<?php

                }

            }

            if (get_theme_mod('sticky_menu_dropshadow')) {

?>
#site-header .sticky {
<?php

                if (get_theme_mod('sticky_menu_shadow_animate')) {

?>
    transform: scale(0.8, 0.8);
    transition: box-shadow 0.3s ease-in-out, transform 0.3s ease-in-out;
    border: 1px solid rgba(0,0,0,0.1);
}
#site-header .shadow {
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
    transform: scale(1, 1);
}
#site-header .sticky:hover {
    transform: scale(1, 1);
<?php

                }

?>
    box-shadow: 0px 4px 17px 4px rgba(0,0,0,0.3);
}
<?php

            }

            if (get_theme_mod('parallax_featured_images')) {

                add_action('wp_footer', array($this, 'oftt_parallax_featured_images'));

?>
body.singular.has-post-thumbnail .featured-media .featured-media-inner {
	height: 100vh;
	overflow: hidden;
	position: relative;
}
body.singular.has-post-thumbnail .featured-media img {
	height: 200vh;
	width: auto;
	max-width: none;
	position: absolute;
	left: 50%;
	transform: translateX(-50%);
	
}
<?php

            }

            if (get_theme_mod('footer_order')) {

                add_action('wp_footer', array($this, 'oftt_footer_order'));

?>
#site-content {
	margin-bottom: 8rem;
}
#site-footer {
	margin-top: 0;
	border-top: 0.1rem solid #dcd7ca;
}
.reduced-spacing.footer-top-visible .footer-nav-widgets-wrapper {
	margin-top: 0;
}
.footer-widgets-outer-wrapper, .footer-top {
	border-bottom: none;
}
<?php

            }

            if (get_theme_mod('footer_sidebars')) {

                add_action('dynamic_sidebar_after', array($this, 'oftt_get_footer_sidebars'), 10, 2);

                if (get_theme_mod('footer_sidebars') == 1) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: auto;
    }
}
@media (min-width: 1220px) {
    .footer-widgets-wrapper {
        margin-left: 0;
        width: auto;
    }
}
<?php

                } elseif (get_theme_mod('footer_sidebars') == 3) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: 33.3333333333%
    }
}
<?php

                } elseif (get_theme_mod('footer_sidebars') == 4) {

?>
@media (min-width: 700px) {
    .footer-widgets {
        width: 25%
    }
}
<?php

                }

            }

            if (get_theme_mod('replace_powered_by_wordpress')) {

                add_action('wp_footer', array($this, 'oftt_replace_powered_by_wordpress'));

            }

            if (absint(get_theme_mod('copyright_link'))) {

                add_action('wp_footer', array($this, 'oftt_copyright_link'));

?>
.footer-credits>.copyright {
    margin: 0 0 0 2.4rem;
}
<?php

            }

            if (get_theme_mod('slider_cover') || (is_page() && get_post_meta(get_the_ID(), 'oftt_cover_slider', true))) {

                add_action('get_template_part_template-parts/content-cover', array($this, 'oftt_inject_slider_cover'), 10, 2);

?>
.cover-slider>.metaslider.ml-slider {
    position: absolute;
    height: 100vh;
    overflow: hidden;
}
.cover-slider>.metaslider.ml-slider .slides img, .cover-slider>.metaslider.ml-slider img {
    height: 100vh !important;
    object-fit: cover;
}
.admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
	height: calc(100vh - 32px) !important;
}
@media (max-width: 600px) {
    .admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
		height: 100vh !important;
    }
}
@media (max-width: 782px) {
    .admin-bar .cover-slider>.metaslider.ml-slider, .admin-bar .cover-slider>.metaslider.ml-slider .slides img, .admin-bar  .cover-slider>.metaslider.ml-slider img {
		height: calc(100vh - 46px) !important;
    }
}
<?php

            }

}

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        public function oftt_archive_cover_template() {

            $cover_taxonomies = get_theme_mod('archive_cover_template');

            if (is_admin()) {

                if (ofttPremium::request_permission() && $cover_taxonomies && is_array($cover_taxonomies)) {

                    foreach ($cover_taxonomies as $cover_taxonomy) {

                        add_action($cover_taxonomy . '_edit_form_fields', array($this, 'oftt_taxonomy_meta_fields'), 10, 2);
                        add_action('edited_' . $cover_taxonomy, array($this, 'oftt_save_taxonomy_meta'), 10, 2);

                    }

                    add_action('admin_enqueue_scripts', array($this, 'oftt_admin_enqueue_scripts'));
                    add_action('wp_ajax_oftt_get_attachment_url', array($this, 'oftt_ajax_get_attachment_url'));

                }

            } else {

                if (ofttPremium::request_permission() && $cover_taxonomies && is_array($cover_taxonomies)) {

                    add_filter('body_class', array($this, 'oftt_twentytwenty_body_classes'));
                    add_filter('get_the_archive_title', array($this, 'oftt_get_the_archive_title'));
                    add_filter('get_the_archive_description', array($this, 'oftt_get_the_archive_title'));
                    add_action('get_template_part_template-parts/pagination', array($this, 'oftt_inject_cover_template'), 10, 2);

                }

            }

    	}

        public function oftt_twentytwenty_body_classes($classes) {

            $taxonomies = get_theme_mod('archive_cover_template');
            $show_cover_template = false;

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    if (is_tax($taxonomy) || ($taxonomy == 'category' && is_category()) || ($taxonomy == 'post_tag' && is_tag())) {

                        $show_cover_template = true;

                    }

                }

            }

            if ($show_cover_template) {

        		$classes[] = 'singular';
        		$classes[] = 'overlay-header';
        		$classes[] = 'template-cover';
        		$classes[] = 'template-full-width';

            }

        	return $classes;

        }

        public function oftt_get_the_archive_title($title) {

            $taxonomies = get_theme_mod('archive_cover_template');
            $show_cover_template = false;

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    if (is_tax($taxonomy) || ($taxonomy == 'category' && is_category()) || ($taxonomy == 'post_tag' && is_tag())) {

                        $show_cover_template = true;

                    }

                }

            }

            if ($show_cover_template) {

                global $wp_query;

                $wp_query->current_post = $wp_query->post_count;

                return '';

            }

            return $title;

        }

        public function oftt_inject_cover_template($slug, $name) {

            $taxonomies = get_theme_mod('archive_cover_template');
            $show_cover_template = false;

            if ($taxonomies && is_array($taxonomies)) {

                foreach ($taxonomies as $taxonomy) {

                    if (is_tax($taxonomy) || ($taxonomy == 'category' && is_category()) || ($taxonomy == 'post_tag' && is_tag())) {

                        $show_cover_template = true;

                    }

                }

            }

            if ($show_cover_template) {

                rewind_posts();

?>
<article class="has-text-align-center header-footer-group">
	<?php
	// On the cover page template, output the cover header.
	$cover_header_style   = '';
	$cover_header_classes = '';

	$color_overlay_style   = '';
	$color_overlay_classes = '';

	$image_url = wp_get_attachment_image_src(get_term_meta(get_queried_object_id(), '_thumbnail_id', true), 'twentytwenty-fullscreen')[0];

	if ( $image_url ) {
		$cover_header_style   = ' style="background-image: url( ' . esc_url( $image_url ) . ' );"';
		$cover_header_classes = ' bg-image';
	}

	// Get the color used for the color overlay.
	$color_overlay_color = get_theme_mod( 'cover_template_overlay_background_color' );
	if ( $color_overlay_color ) {
		$color_overlay_style = ' style="color: ' . esc_attr( $color_overlay_color ) . ';"';
	} else {
		$color_overlay_style = '';
	}

	// Get the fixed background attachment option.
	if ( get_theme_mod( 'cover_template_fixed_background', true ) ) {
		$cover_header_classes .= ' bg-attachment-fixed';
	}

	// Get the opacity of the color overlay.
	$color_overlay_opacity  = get_theme_mod( 'cover_template_overlay_opacity' );
	$color_overlay_opacity  = ( false === $color_overlay_opacity ) ? 80 : $color_overlay_opacity;
	$color_overlay_classes .= ' opacity-' . $color_overlay_opacity;
	?>

	<div class="cover-header <?php echo $cover_header_classes; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- static output ?>"<?php echo $cover_header_style; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- We need to double check this, but for now, we want to pass PHPCS ;) ?>>
		<div class="cover-header-inner-wrapper screen-height"<?php echo ($image_url ? '' : ' style="min-height: auto; justify-content: flex-start;"'); ?>>
			<div class="cover-header-inner">
				<div class="cover-color-overlay color-accent<?php echo esc_attr( $color_overlay_classes ); ?>"<?php echo $color_overlay_style; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- We need to double check this, but for now, we want to pass PHPCS ;) ?>></div>

					<header class="entry-header has-text-align-center">
						<div class="entry-header-inner section-inner medium">

							<h1 class="entry-title"><?php echo single_cat_title('', false); ?></h1>

								<?php

                            $sub_title = apply_filters( 'oftt_cover_template_sub_title', false );

							if ( $sub_title ) {

									?>

							<h2 class="entry-title"><?php echo esc_html($sub_title); ?></h2>

									<?php

                            }

							if ( term_description() ) {

	                            $intro_text_width = '';
									?>

									<div class="intro-text section-inner max-percentage<?php echo esc_attr( $intro_text_width ); ?>">
										<?php echo term_description(); ?>
									</div>

									<?php

                            } elseif ( $image_url ) {
								?>

								<div class="to-the-content-wrapper">

									<a href="#post-inner" class="to-the-content fill-children-current-color">
										<?php twentytwenty_the_theme_svg( 'arrow-down' ); ?>
										<div class="screen-reader-text"><?php _e( 'Scroll Down', 'twentytwenty' ); ?></div>
									</a><!-- .to-the-content -->

								</div><!-- .to-the-content-wrapper -->

								<?php
                            }
							?>

						</div><!-- .entry-header-inner -->
					</header><!-- .entry-header -->

			</div><!-- .cover-header-inner -->
		</div><!-- .cover-header-inner-wrapper -->
	</div><!-- .cover-header -->

	<div class="post-inner" id="post-inner">

		<?php

    $content = apply_filters( 'oftt_cover_template_content', false );

	if ( $content ) {

		echo $content;

    } else {

    	if ( have_posts() ) {

    		$i = 0;

    		while ( have_posts() ) {
    			$i++;
    			if ( $i > 1 ) {
    				echo '<hr class="post-separator styled-separator is-style-wide section-inner" aria-hidden="true" />';
    			}
    			the_post();

    			get_template_part( 'template-parts/content', get_post_type() );

    		}
    	}

    }

		?>

	</div><!-- .post-inner -->
</article><!-- .post -->
<?php

            }

        }

        public function oftt_taxonomy_meta_fields($tag, $taxonomy) {

            wp_nonce_field('oftt-meta', 'oftt-meta-nonce');

?>
<table class="form-table" role="presentation">
    <tr class="form-field term-featured-image-wrap">
        <th scope="row"><label for="_thumbnail_id"><?php _e('Featured Image', 'options-for-twenty-twenty'); ?></label></th>
        <td>
<?php

        $image_id = absint(get_term_meta($tag->term_id, '_thumbnail_id', true));

        if ($image_id > 0) {

?>
            <img id="_thumbnail_id_preview_image" src="<?php echo wp_get_attachment_image_src($image_id, 'medium')[0]; ?>" />
<?php

        } else {

?>
            <img id="_thumbnail_id_preview_image" />
<?php

        }
?>
            <br />
            <input id="_thumbnail_id" name="_thumbnail_id" type="hidden" value="<?php if ($image_id) { echo esc_html($image_id); } ?>" />
            <input type="button" class="button-primary" value="<?php esc_attr_e('Select Image', 'options-for-twenty-twenty' ); ?>" id="_thumbnail_id_media_manager" data-button="<?php echo wp_create_nonce('oftt-meta'); ?>" />
            <input type="button" class="button" value="<?php esc_attr_e('Clear', 'options-for-twenty-twenty' ); ?>" onclick="jQuery('input#_thumbnail_id').removeAttr('value'); jQuery('img#_thumbnail_id_preview_image').removeAttr('src').replaceWith(jQuery('img#_thumbnail_id_preview_image').clone());" />
        </td>
    </tr>
</table>

<script type="text/javascript">
jQuery(document).ready( function() {
    jQuery('input#_thumbnail_id_media_manager').click(function(e) {
        e.preventDefault();
        var image_frame;
        if(image_frame){
            image_frame.open();
        }
        image_frame = wp.media({
            title: '<?php _e('Select Media', 'options-for-twenty-twenty'); ?>',
            multiple : false,
            library : {
                type : 'image',
            }
        });
        image_frame.on('close',function() {
            var selection =  image_frame.state().get('selection');
            var gallery_ids = [];
            var my_index = 0;
            selection.each(function(attachment) {
                gallery_ids[my_index] = attachment.id;
                my_index++;
            });
            var ids = gallery_ids.join(",");
            jQuery('input#_thumbnail_id').val(ids);
            ofttRefreshImage(ids, '_thumbnail_id');
        });
        image_frame.on('open',function() {
            var selection =  image_frame.state().get('selection');
            ids = jQuery('input#_thumbnail_id').val().split(',');
            ids.forEach(function(id) {
                attachment = wp.media.attachment(id);
                attachment.fetch();
                selection.add( attachment ? [ attachment ] : [] );
            });
        });
        image_frame.open();
    });
});
function ofttRefreshImage(the_id, option_type){
    var data = {
        action: 'oftt_get_attachment_url',
        id: the_id,
        _wpnonce: jQuery('input#' + option_type + '_media_manager').attr('data-button')
    };
    jQuery.get(ajaxurl, data, function(response) {
        if(response.success === true) {
            jQuery('#' + option_type + '_preview_image').attr('src', response.data.url);
        }
    });
}
</script>

<?php

        }

        public function oftt_admin_enqueue_scripts($hook_suffix) {

            if ($hook_suffix != 'term.php') {

                return;

            }

            wp_enqueue_media();

        }

        public function oftt_ajax_get_attachment_url() {

            check_ajax_referer('oftt-meta');

            if (current_user_can('manage_options') && isset($_GET['id']) && absint($_GET['id']) > 0) {

                $data = array(
                    'url' => wp_get_attachment_image_src(absint($_GET['id']), 'medium')[0]
                );

                wp_send_json_success($data);

            } else {

                wp_send_json_error();

            }

        }

        public function oftt_save_taxonomy_meta($term_id, $tt_id) {

            if (!isset($_POST['oftt-meta-nonce']) || !wp_verify_nonce($_POST['oftt-meta-nonce'], 'oftt-meta') || !current_user_can('manage_options')) {

                return;

            }

            if (isset($_POST['_thumbnail_id']) && absint($_POST['_thumbnail_id'])) {

                update_term_meta($term_id, '_thumbnail_id', absint($_POST['_thumbnail_id']));

            } else {

                delete_term_meta($term_id, '_thumbnail_id');

            }

        }

        function oftt_inject_background_image_true_parallax() {

            if (set_url_scheme(get_background_image())) {

?>
<script type="text/javascript">
    document.body.style.backgroundSize = 'auto 300vh';
	document.body.style.backgroundPosition = '50% -' + Math.round(((2 * window.innerHeight) * window.scrollY) / (document.body.clientHeight - window.innerHeight)) +  'px';
    window.addEventListener('scroll', function() {
    	if (window.matchMedia('(min-width: 1000px)').matches) {
    		document.body.style.backgroundPosition = '50% -' + Math.round(((2 * window.innerHeight) * window.scrollY) / (document.body.clientHeight - window.innerHeight)) +  'px';
        }
    });
</script>
<?php

            }

        }

        public function oftt_get_search_form($form, $args) {

            $new_form = '';

            foreach(explode("\n", $form) as $line) {

            	if('</form>' === trim($line)) {

            		$new_form .= '<input type="hidden" name="post_type" value="' . esc_attr(get_theme_mod('search_post_type')) . '" />' . PHP_EOL;

            	}

            	$new_form .= $line . PHP_EOL;

            }

            return $new_form;

        }

        function oftt_inject_sidebar() {

            $inject_sidebar_args = get_theme_mod('inject_sidebar');

            if (is_archive()) {

                global $wp_query;
                $taxonomy = $wp_query->get_queried_object();

            }

            if (
                is_active_sidebar('sidebar') && (
                    in_array('all', $inject_sidebar_args) ||
                    (in_array('front_page', $inject_sidebar_args) && is_front_page()) ||
                    (in_array('home', $inject_sidebar_args) && is_home()) ||
                    (in_array('single', $inject_sidebar_args) && is_single()) ||
                    (in_array('archive', $inject_sidebar_args) && is_archive()) ||
                    (is_single() && in_array('post_type/' . get_post_type() , $inject_sidebar_args)) ||
                    (is_page() && !is_front_page() && in_array('post_type/page', $inject_sidebar_args)) ||
                    (is_archive() && is_object($taxonomy) && isset($taxonomy->taxonomy) && in_array('taxonomy/' . get_post_type() . '/' . $taxonomy->taxonomy , $inject_sidebar_args)) ||
                    ((is_single() || is_page()) && get_post_meta(get_the_ID(), 'oftt_show_sidebar', true) == '1')
                )
            ) {

?>
<aside id="sidebar" class="widget-area" role="complementary" aria-label="<?php esc_attr_e( 'Sidebar', 'options-for-twenty-twenty' ); ?>">
<?php dynamic_sidebar('sidebar'); ?>
</aside>
<script type="text/javascript">
    (function () {
        var wrapper = document.createElement('div'),
            content,
            sidebar = document.getElementById('sidebar');
        if (!!document.getElementById('primary')) {
            content = document.getElementById('primary');
        } else {
            content = <?php if (is_single() or is_page()) { ?>document.getElementsByClassName('post-inner')[0];<?php } else { ?>document.getElementById('site-content');<?php } ?>
        }
        wrapper.id = 'site-content-wrapper';
        content.parentNode.insertBefore(wrapper, content);
        wrapper.appendChild(content);
        wrapper.appendChild(sidebar);
<?php

                if (is_archive()) {

?>
       if (!!document.getElementsByClassName('archive-header')) {
           document.body.insertBefore(document.getElementsByClassName('archive-header')[0], document.getElementById('site-content-wrapper'));
       }
<?php

                }

?>
    }());
</script>
<?php

            }

        }

        function oftt_toggle_use_dashicon() {

            if (!get_theme_mod('nav_toggle_dashicon') && get_theme_mod('toggle_use_dashicon') == 1) {

                set_theme_mod('nav_toggle_dashicon', 'menu');
                remove_theme_mod('toggle_use_dashicon');

            }

?>
<script type="text/javascript">
    (function () {
        var navToggles = document.querySelectorAll('.nav-toggle .toggle-icon');
            Array.prototype.forEach.call(navToggles, function(navToggle) {
            navToggle.innerHTML = '<span alt="Menu" class="dashicons dashicons-dashicons dashicons-<?php echo get_theme_mod('nav_toggle_dashicon'); ?>"></span>';
        });
    }());
</script>
<?php

        }

        function oftt_enqueue_scripts() {

            if (get_theme_mod('nav_toggle_dashicon')) {

                wp_enqueue_style('dashicons');

            }

        }

        function oftt_menu_widgets($nav_menu, $args) {

            if (ofttPremium::request_permission() && isset($args->theme_location) && $args->theme_location == 'expanded') {

		        if (is_active_sidebar('expanded-1')) {

                    $nav_menu = '<div class="expanded-widgets">' . $this->oftt_get_dynamic_sidebar('expanded-1') . '</div>' . $nav_menu;

                }

		        if (is_active_sidebar('expanded-2')) {

                    $nav_menu =  $nav_menu . '<div class="expanded-widgets">' . $this->oftt_get_dynamic_sidebar('expanded-2') . '</div>';

                }

            }

            if (ofttPremium::request_permission() && isset($args->theme_location) && $args->theme_location == 'mobile') {

		        if (is_active_sidebar('mobile-1')) {

                    $nav_menu = '<div class="mobile-widgets">' . $this->oftt_get_dynamic_sidebar('mobile-1') . '</div>' . $nav_menu;

                }

		        if (is_active_sidebar('mobile-2')) {

                    $nav_menu =  $nav_menu . '<div class="mobile-widgets">' . $this->oftt_get_dynamic_sidebar('mobile-2') . '</div>';

                }

            }

            return $nav_menu;

        }

        function oftt_get_dynamic_sidebar($index = 1) {

            $sidebar_contents = '';
            ob_start();
            dynamic_sidebar($index);
            $sidebar_contents = ob_get_clean();

            return $sidebar_contents;

        }

        function oftt_sticky_menu() {

?>
<script type="text/javascript">
    (function () {<?php

        if (get_theme_mod('sticky_mobile_menu') == 'bar' || get_theme_mod('sticky_desktop_menu') == 'bar') {

            if (get_theme_mod('sticky_mobile_menu') == 'bar') { $width_condition = 'document.body.clientWidth < 1000'; }

            if (get_theme_mod('sticky_desktop_menu') == 'bar') { $width_condition = 'document.body.clientWidth >= 1000'; }

            if (get_theme_mod('sticky_mobile_menu') == 'bar' && get_theme_mod('sticky_desktop_menu') == 'bar') { $width_condition = '1 == 1'; }

?>
                if (typeof document.getElementsByClassName('overlay-header')[0] === 'undefined') {
                    function setupWindowResize() {
                        var windowResize;
                        (windowResize = function(){
                            if (<?php echo $width_condition; ?>) {
                                document.body.style.marginTop = document.getElementById('site-header').clientHeight + 'px';
                            } else {
                                document.body.style.marginTop = 0;
                            }
                        }).call();
                        window.onresize = windowResize;
                        document.getElementsByClassName('to-the-top')[0].href = '#site-content';
                    }
                    if (
                        document.readyState === 'complete' ||
                        (document.readyState !== 'loading' && !document.documentElement.doScroll)
                    ) {
                        setupWindowResize();
                    } else {
                        document.addEventListener('DOMContentLoaded', setupWindowResize());
                    }
                }
                window.addEventListener('scroll', function() {
                    var siteHeader = document.getElementById('site-header');
                    if (!siteHeader.classList.contains('shadow')) {
                        siteHeader.classList.add('shadow');
                        setTimeout(function() {
                            siteHeader.classList.remove('shadow');
                        }, 1800);
                    }
                });
<?php

        }

            if (get_theme_mod('sticky_mobile_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') {

                if (get_theme_mod('sticky_mobile_menu') == 'button') { $width_condition = 'document.body.clientWidth < 1000'; }

                if (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden') { $width_condition = 'document.body.clientWidth >= 1000'; }

                if (get_theme_mod('sticky_mobile_menu') == 'button' && (get_theme_mod('sticky_desktop_menu') == 'button' || get_theme_mod('sticky_desktop_menu') == 'hidden')) { $width_condition = '1 == 1'; }

?>

        window.addEventListener('scroll', function() {
            var navToggles = document.getElementById('site-header').getElementsByClassName('nav-toggle');
            if (<?php echo $width_condition; ?>) {
                Array.prototype.forEach.call(navToggles, function(navToggle) {
                    var siteHeaderHeight = document.getElementById('site-header').clientHeight;
                    var adminBar = document.getElementById('wpadminbar');
                    if (adminBar !== null && document.body.clientWidth <= 600) { siteHeaderHeight += adminBar.clientHeight; }
                    if ((window.pageYOffset || (document.documentElement || document.body.parentNode || document.body).scrollTop) > siteHeaderHeight) {
                        if (!navToggle.classList.contains('sticky')) {
                            navToggle.classList.add('sticky');
                            if (!navToggle.classList.contains('shadow')) {
                                navToggle.classList.add('shadow');
                                setTimeout(function() {
                                    navToggle.classList.remove('shadow');
                                }, 600);
                            }
                        }
                    } else {
                        if (navToggle.classList.contains('sticky')) {
                            navToggle.classList.remove('sticky');
                        }
                    }
                });
            } else {
                Array.prototype.forEach.call(navToggles, function(navToggle) {
                    if (navToggle.classList.contains('sticky')) {
                        navToggle.classList.remove('sticky');
                    }
                });
            }
        });<?php

            }

?>
    }());
</script>
<?php

        }

        function oftt_widgets_init() {

            if (ofttPremium::request_permission() == true) {

                register_sidebar(array(
                    'name'          => __( 'Sidebar', 'options-for-twenty-twenty' ),
                    'id'            => 'sidebar',
                    'description'   => __( 'Widgets in this area will be displayed in your website\'s sidebar.', 'options-for-twenty-twenty' ),
                    'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
                    'after_title'   => '</h2>',
                    'before_widget' => '<section id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</section>'
		        ));

    	        register_sidebar(array(
				    'name'          => __('Expanded #1', 'options-for-twenty-twenty'),
				    'id'            => 'expanded-1',
				    'description'   => __('Widgets in this area will be displayed above the expanded menu.', 'options-for-twenty-twenty'),
		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
    			    'name'          => __('Expanded #2', 'options-for-twenty-twenty'),
    			    'id'            => 'expanded-2',
    			    'description'   => __('Widgets in this area will be displayed below the expanded menu.', 'options-for-twenty-twenty'),
    	            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
    	            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
    	            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
				    'name'          => __('Mobile #1', 'options-for-twenty-twenty'),
				    'id'            => 'mobile-1',
				    'description'   => __('Widgets in this area will be displayed above the mobile menu.', 'options-for-twenty-twenty'),
		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
		            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
		            'after_widget'  => '</div></div>'
                ));

    	        register_sidebar(array(
    			    'name'          => __('Mobile #2', 'options-for-twenty-twenty'),
    			    'id'            => 'mobile-2',
    			    'description'   => __('Widgets in this area will be displayed below the mobile menu.', 'options-for-twenty-twenty'),
    	            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
    	            'after_title'   => '</h2>',
                    'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
    	            'after_widget'  => '</div></div>'
                ));

                if (get_theme_mod('footer_sidebars')) {

                    if (get_theme_mod('footer_sidebars') && get_theme_mod('footer_sidebars') == '1') {

            	        unregister_sidebar('sidebar-2');

                    }

                    if (get_theme_mod('footer_sidebars') && (get_theme_mod('footer_sidebars') == '4' || get_theme_mod('footer_sidebars') == '3')) {

            	        register_sidebar(array(
        				    'name'          => __('Footer #3', 'options-for-twenty-twenty'),
        				    'id'            => 'sidebar-3',
        				    'description'   => __('Widgets in this area will be displayed in the third column in the footer.', 'options-for-twenty-twenty'),
        		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
        		            'after_title'   => '</h2>',
                            'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
        		            'after_widget'  => '</div></div>'
                        ));

                    }

                    if (get_theme_mod('footer_sidebars') && get_theme_mod('footer_sidebars') == '4') {

            	        register_sidebar(array(
        				    'name'          => __('Footer #4', 'options-for-twenty-twenty'),
        				    'id'            => 'sidebar-4',
        				    'description'   => __('Widgets in this area will be displayed in the fourth column in the footer.', 'options-for-twenty-twenty'),
        		            'before_title'  => '<h2 class="widget-title subheading heading-size-3">',
        		            'after_title'   => '</h2>',
                            'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
        		            'after_widget'  => '</div></div>'
                        ));

                    }

                }

            }

        }

        public function oftt_parallax_featured_images() {

            if (is_singular() && has_post_thumbnail()) {

?>
<script type="text/javascript">
    var parallaxFeaturedScroll = function() {
        var $imageElement = document.getElementsByClassName('attachment-post-thumbnail')[0],
        $headerElement = document.getElementsByClassName('featured-media-inner')[0];
        if (((window.scrollY + window.innerHeight) > (window.pageYOffset + $headerElement.getBoundingClientRect().top)) && (window.scrollY < ((window.pageYOffset + $headerElement.getBoundingClientRect().top) + $headerElement.offsetHeight))) {
        	$imageElement.style.objectPosition = '-50% -' + Math.round((window.scrollY + window.innerHeight - (window.pageYOffset + $headerElement.getBoundingClientRect().top)) / (window.innerHeight +$headerElement.offsetHeight) * window.innerHeight) + 'px';
        }
    };
    var parallaxFeatured = function() {
        parallaxFeaturedScroll();
        window.addEventListener('scroll', function() {
            parallaxFeaturedScroll();
        });
    };
    if (
        document.readyState === 'complete' ||
        (document.readyState !== 'loading' && !document.documentElement.doScroll)
    ) {
        parallaxFeatured();
    } else {
        document.addEventListener('DOMContentLoaded', parallaxFeatured);
    }
</script>
<?php

            }

        }

        function oftt_footer_order() {

            $footer_order = get_theme_mod('footer_order');

?>
<script type="text/javascript">
    (function () {
        var footerContent = [];
        if (typeof document.getElementsByClassName('footer-top')[0] !== 'undefined' && typeof document.getElementsByClassName('footer-widgets-outer-wrapper')[0] !== 'undefined') {
            document.getElementsByClassName('footer-nav-widgets-wrapper')[0].parentNode.insertBefore(document.getElementsByClassName('footer-nav-widgets-wrapper')[0].cloneNode(true), document.getElementsByClassName('footer-nav-widgets-wrapper')[0].nextSibling);
            document.getElementsByClassName('footer-top')[1].parentNode.removeChild(document.getElementsByClassName('footer-top')[1]);
            document.getElementsByClassName('footer-widgets-outer-wrapper')[0].parentNode.removeChild(document.getElementsByClassName('footer-widgets-outer-wrapper')[0]);
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[1] = document.getElementsByClassName('footer-nav-widgets-wrapper')[1];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[<?php echo $footer_order[0]; ?>].parentNode.insertBefore(footerContent[<?php echo $footer_order[0]; ?>], document.getElementById('site-content').nextSibling);
            footerContent[<?php echo $footer_order[1]; ?>].parentNode.insertBefore(footerContent[<?php echo $footer_order[1]; ?>], footerContent[<?php echo $footer_order[0]; ?>].nextSibling);
            footerContent[<?php echo $footer_order[2]; ?>].parentNode.insertBefore(footerContent[<?php echo $footer_order[2]; ?>], footerContent[<?php echo $footer_order[1]; ?>].nextSibling);
        } else if (typeof document.getElementsByClassName('footer-top')[0] === 'undefined' && typeof document.getElementsByClassName('footer-widgets-outer-wrapper')[0] === 'undefined') {
        } else if (typeof document.getElementsByClassName('footer-top')[0] === 'undefined') {
<?php

if (strpos($footer_order, '1') > strpos($footer_order, '2')) {

?>
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[0].parentNode.insertBefore(footerContent[0], footerContent[2].nextSibling);
<?php

}

?>
        } else {
<?php

if (strpos($footer_order, '0') > strpos($footer_order, '2')) {

?>
            footerContent[0] = document.getElementsByClassName('footer-nav-widgets-wrapper')[0];
            footerContent[2] = document.getElementById('site-footer');
            footerContent[0].parentNode.insertBefore(footerContent[0], footerContent[2].nextSibling);
<?php

}

?>
        }
    }());
</script>
<?php

        }

        function oftt_get_footer_sidebars($index, $has_widgets) {

            if ($index == 'sidebar-2') {

		        if (is_active_sidebar('sidebar-3')) {

?>
<div class="footer-widgets column-three grid-item">
<?php dynamic_sidebar( 'sidebar-3' ); ?>
</div>
<script type="text/javascript">
    (function () {
        var sidebarWrapper = document.getElementsByClassName('footer-widgets-wrapper')[0],
        newSidebar = sidebarWrapper.getElementsByClassName('column-three')[0];
        sidebarWrapper.appendChild(newSidebar);
    }());
</script>
<?php

                }

		        if (get_theme_mod('footer_sidebars') == 4 && is_active_sidebar('sidebar-4')) {

?>
<div class="footer-widgets column-four grid-item">
<?php dynamic_sidebar( 'sidebar-4' ); ?>
</div>
<script type="text/javascript">
    (function () {
        var sidebarWrapper = document.getElementsByClassName('footer-widgets-wrapper')[0],
        newSidebar = sidebarWrapper.getElementsByClassName('column-four')[0];
        sidebarWrapper.appendChild(newSidebar);
    }());
</script>
<?php

                }

            }

        }

        function oftt_replace_powered_by_wordpress() {

?>
<script type="text/javascript">
    (function() {
        var el = document.getElementsByClassName('powered-by-wordpress')[0];
        var newEl = document.createElement('p');
        newEl.innerHTML = '<?php echo addslashes(get_theme_mod('replace_powered_by_wordpress')); ?>';
        newEl.classList.add("powered-by-wordpress");
        el.parentNode.replaceChild(newEl, el);
    })();
</script>
<?php

        }

        function oftt_copyright_link() {

            $page = get_post(absint(get_theme_mod('copyright_link')));

            if ($page) {

?>
<p class="copyright"><a class="copyright-link" href="<?php echo esc_url(get_permalink($page)); ?>"><?php echo esc_html($page->post_title); ?></a></p>
<script type="text/javascript">
    (function () {
        document.getElementsByClassName('footer-copyright')[0].parentNode.insertBefore(document.getElementsByClassName('copyright')[0], document.getElementsByClassName('footer-copyright')[0].nextSibling);
    }());
</script>
<?php

            }

        }

        function oftt_inject_slider_cover($slug, $name) {

            $slider_id = get_post_meta(get_the_ID(), 'oftt_cover_slider', true);

            if (!$slider_id) {

                $slider_id = get_theme_mod('slider_cover');

            }

            $slider_post_type = get_post_type($slider_id);

            if ($slider_post_type == 'ml-slider' && class_exists('MetaSliderPlugin')) {

?>
<div class="cover-slider">
<?php echo do_shortcode('[metaslider id="' . $slider_id . '"]'); ?>
</div>
<?php

            }

        }

        function oftt_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'oftt_add_theme_options_metabox'));

            if (ofttPremium::request_permission() == true) {

                add_action('save_post', array($this, 'oftt_save_theme_options_meta'), 10, 2);

            }

        }

        function oftt_add_theme_options_metabox() {

            add_meta_box('oftt_meta_box', __('Theme Options', 'options-for-twenty-twenty'), array($this, 'oftt_render_theme_options_metabox'), array('post', 'page'), 'side');

        }

        function oftt_render_theme_options_metabox($post) {

            $upgrade_link = '<a href="' . ofttCommon::upgrade_link() . '" title="' . __('Upgrade Options for Twenty Twenty', 'options-for-twenty-twenty') . '">' . __('Upgrade Options for Twenty Twenty', 'options-for-twenty-twenty') . '</a>';

            if (get_option('oftt_purchased') == false) {

                if (get_option('oftt_trial_date') && time() < (strtotime('+1 week', get_option('oftt_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('oftt_trial_date'))) - time())/60/60/24);
                    $expiring_text = '<p><span class="attention">' . sprintf(_n('Options for Twenty Twenty Premium plugin trial expires in less than %s day!', 'Options for Twenty Twenty Premium plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-twenty'), $expiring_in) . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'options-for-twenty-twenty') . '</p>');

                } elseif (get_option('oftt_trial_date') && time() > (strtotime('+1 week', get_option('oftt_trial_date')))) {

                    $expiring_text = '<p><span class="attention">' . __('Options for Twenty Twenty Premium plugin free trial has expired', 'options-for-twenty-twenty') . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to use these options.', 'options-for-twenty-twenty') . '</p>');

                }

            }

            wp_nonce_field('options-for-twenty-twenty', 'oftt-meta-nonce');

            if (ofttPremium::request_permission() == true) {

                if (($post->post_type == 'page' && get_theme_mod('force_page_template')) || ($post->post_type == 'post' && get_theme_mod('force_page_template'))) {

?>
<input type="checkbox" name="oftt-override-force-template" id="oftt-override-force-template" value="1" <?php checked(get_post_meta($post->ID, 'oftt_override_force_template', true), '1' ); ?> />
<label for="oftt-override-force-template"><?php _e('Override Force Template', 'options-for-twenty-twenty'); ?></label>
<br />
<?php

                }

?>
<input type="checkbox" name="oftt-hide-header" id="oftt-hide-header" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_header', true), '1' ); ?> />
<label for="oftt-hide-header"><?php echo ((get_theme_mod('hide_all_headers') ? __('Show Header', 'options-for-twenty-twenty') : __('Hide Header', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-hide-header-title" id="oftt-hide-header-title" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_header_title', true), '1' ); ?> />
<label for="oftt-hide-header-title"><?php echo ((get_theme_mod('hide_all_header_titles') ? __('Show Header Title', 'options-for-twenty-twenty') : __('Hide Header Title', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-hide-featured-image" id="oftt-hide-featured-image" value="1" <?php checked(get_post_meta($post->ID, 'oftt_hide_featured_image', true), '1' ); ?> />
<label for="oftt-hide-featured-image"><?php echo ((get_theme_mod('hide_all_featured_images') ? __('Show Featured Image', 'options-for-twenty-twenty') : __('Hide Featured Image', 'options-for-twenty-twenty'))); ?></label>
<br />
<input type="checkbox" name="oftt-show-sidebar" id="oftt-show-sidebar" value="1" <?php checked(get_post_meta($post->ID, 'oftt_show_sidebar', true), '1' ); ?> />
<label for="oftt-show-sidebar"><?php _e('Show Sidebar', 'options-for-twenty-twenty'); ?></label>
<?php

                if ($post->post_type == 'page') {

                    $installed_sliders = array();

                    if (class_exists('MetaSliderPlugin')) {

                        $installed_sliders[] = 'ml-slider';

                    }

                    $sliders_array = array('' => 'No slider');

                    if (!empty($installed_sliders)) {

                        $available_sliders = get_posts(array(
                            'post_type' => $installed_sliders,
                            'posts_per_page' => -1,
                        ));

                        foreach ($available_sliders as $available_slider) {

                            $sliders_array[$available_slider->ID] = $available_slider->post_title;

                        }

                    }

?>
<br />
<label for="oftt-cover-slider"><?php _e('Cover Template Slider:', 'options-for-twenty-twenty'); ?> (<?php printf(
                        wp_kses(__('Place a <a href="%s">MetaSlider</a> slider in the background of the Cover Template', 'options-for-twenty-twenty'), array('a' => array('href' => array()))),
                            esc_url(add_query_arg( array(
                                's' => 'ml-slider',
                                'tab' => 'search',
                                'type' => 'term'
                        ), admin_url('plugin-install.php')))
                    ); ?>)</label>
<select name="oftt-cover-slider" id="oftt-cover-slider" class="components-select-control__input">
<?php

                    foreach ($sliders_array as $key => $value) {

?>
<option value="<?php echo $key; ?>" <?php selected(get_post_meta($post->ID, 'oftt_cover_slider', true), $key ); ?>><?php echo esc_html($value); ?></option>
<?php

                    }

?>
</select>
<?php

                }

            } else {

?>

<p><?php echo $upgrade_link; ?> <?php _e('to hide the header, header title or featured image, or to show the sidebar or to show a slider in the page Cover Template.', 'options-for-twenty-twenty'); ?></p>

<?php
            }

        }

        function oftt_save_theme_options_meta($post_id, $post) {

            if (!isset( $_POST['oftt-meta-nonce'] ) || !wp_verify_nonce($_POST['oftt-meta-nonce'], 'options-for-twenty-twenty')) {

                return;

            }

            $post_type = get_post_type_object( $post->post_type );

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['oftt-override-force-template']) && $_POST['oftt-override-force-template'] == '1') {

                update_post_meta($post_id, 'oftt_override_force_template', 1);

            } else {

                delete_post_meta($post_id, 'oftt_override_force_template');

            }

            if (isset($_POST['oftt-hide-header']) && $_POST['oftt-hide-header'] == '1') {

                update_post_meta($post_id, 'oftt_hide_header', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_header');

            }

            if (isset($_POST['oftt-hide-header-title']) && $_POST['oftt-hide-header-title'] == '1') {

                update_post_meta($post_id, 'oftt_hide_header_title', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_header_title');

            }

            if (isset($_POST['oftt-hide-featured-image']) && $_POST['oftt-hide-featured-image'] == '1') {

                update_post_meta($post_id, 'oftt_hide_featured_image', 1);

            } else {

                delete_post_meta($post_id, 'oftt_hide_featured_image');

            }

            if (isset($_POST['oftt-show-sidebar']) && $_POST['oftt-show-sidebar'] == '1') {

                update_post_meta($post_id, 'oftt_show_sidebar', 1);

            } else {

                delete_post_meta($post_id, 'oftt_show_sidebar');

            }

            if (isset($_POST['oftt-cover-slider']) && absint($_POST['oftt-cover-slider'])) {

                update_post_meta($post_id, 'oftt_cover_slider', absint($_POST['oftt-cover-slider']));

            } else {

                delete_post_meta($post_id, 'oftt_cover_slider');

            }

        }

        public function oftt_twentytwenty_social_icons_map($map = array()) {

            if (ofttPremium::request_permission() == true && has_nav_menu('social')) {

                $map['spectrum'] = array('spectrum.chat');

            }

            return $map;

        }

        public function oftt_twentytwenty_svg_icons_social($social_icons = array()) {

            if (ofttPremium::request_permission() == true && has_nav_menu('social')) {

                $social_icons['spectrum'] = '<svg width="32" height="32" viewBox="0 0 32 32" version="1.1" xmlns="http://www.w3.org/2000/svg"><path id="Subtract" fill-rule="evenodd" clip-rule="evenodd" d="M6 14.5C6 15.3284 6.67157 16 7.5 16H9C12.866 16 16 19.134 16 23V24.5C16 25.3284 16.6716 26 17.5 26H24.5C25.3284 26 26 25.3284 26 24.5V23C26 13.6111 18.3889 6 9 6H7.5C6.67157 6 6 6.67157 6 7.5V14.5Z" fill="black"/></svg>';

            }

            return $social_icons;

        }

	}

    if (!class_exists('ofttPremium')) {

        require_once(dirname(__FILE__) . '/includes/class-oftt-premium.php');

    }

    function options_for_twenty_twenty_premium_init() {

        global $options_for_twenty_twenty_object;

        if (isset($options_for_twenty_twenty_object) && is_object($options_for_twenty_twenty_object) && class_exists('ofttCommon')) {

            if (is_admin()) {

                ofttPremium::start_trial();

            }

            $options_for_twenty_twenty_premium_object = new options_for_twenty_twenty_premium_class();

        } elseif (!class_exists('options_for_twenty_twenty_class')) {

            add_action('admin_notices', 'ofttPremium::free_plugin_notice');

        }

    }

    add_action('plugins_loaded', 'options_for_twenty_twenty_premium_init');

}

?>
